%global codename fuerte
%global shortname image_common

Name:		ros-%{codename}-image-common
Version:	1.8.0
Release:	2%{?dist}
Summary:	Common ROS code for working with images
License:	BSD
URL:		http://ros.org/wiki/image_common
Source0:	https://code.ros.org/svn/release/download/stacks/image_common/image_common-%{version}/image_common-%{version}.tar.bz2
# Fuerte doesn't use common_rosdeps anymore.
Patch0:		ros-image-common-no-common-rosdeps.patch
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	ros-%{codename}-pluginlib-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	cmake, python-yaml, yaml-cpp-devel
BuildRequires:	chrpath
Provides:	ros-%{shortname} = %{version}-%{release}
Provides:	ros-image-common = %{version}-%{release}

%description
Common code for working with images in ROS.

%package devel
Summary:	Development files for ROS image_common
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Requires:	ros-%{codename}-pluginlib-devel, ros-%{codename}-common-msgs-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}
Provides:	ros-image-common-devel = %{version}-%{release}

%description devel
Development files for ROS image_common.

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}
%patch0 -p1 -b .nocommonrosdeps

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
for i in camera_calibration_parsers camera_info_manager image_transport polled_camera; do
  pushd $i
  mkdir build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

#camera_calibration_parsers
pushd camera_calibration_parsers
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/bin
mkdir -p %{buildroot}%{_bindir}
cp -a bin/convert %{buildroot}%{_bindir}/ros-convert
ln -s %{_bindir}/ros-convert %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/bin/convert
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/lib
mkdir -p %{buildroot}%{_libdir}
cp -a lib/libcamera_calibration_parsers.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libcamera_calibration_parsers.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/lib/libcamera_calibration_parsers.so
popd

#camera_info_manager
pushd camera_info_manager
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_info_manager
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_info_manager/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_info_manager/lib
cp lib/libcamera_info_manager.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libcamera_info_manager.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_info_manager/lib/libcamera_info_manager.so
popd

#image_transport
pushd image_transport
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport
cp -a *.dox *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport/bin
for i in list_transports republish; do
  cp -a bin/$i %{buildroot}%{_bindir}/ros-$i
  ln -s %{_bindir}/ros-$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport/bin/$i
done
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport/lib
cp -a lib/libimage_transport.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libimage_transport.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/image_transport/lib/libimage_transport.so
popd

#polled_camera
pushd polled_camera
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera
cp -a *.dox *.xml include srv srv_gen %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera/
cp -a bin/poller %{buildroot}%{_bindir}/ros-poller
ln -s %{_bindir}/ros-poller %{buildroot}%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/bin/poller
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera/lib
cp -a lib/libpolled_camera.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libpolled_camera.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera/lib/libpolled_camera.so
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera/src
mkdir -p %{buildroot}%{python_sitelib}
cp -a src/polled_camera %{buildroot}%{python_sitelib}/
ln -s %{python_sitelib}/polled_camera %{buildroot}%{_datadir}/ros-stacks/%{shortname}/polled_camera/src/polled_camera
popd

chrpath -d %{buildroot}%{_bindir}/* 
chrpath -d %{buildroot}%{_libdir}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/ros-convert
%{_bindir}/ros-list_transports
%{_bindir}/ros-poller
%{_bindir}/ros-republish
%{_datadir}/ros-stacks/%{shortname}/
%exclude %{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/camera_info_manager/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/image_transport/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/polled_camera/include/
%{_libdir}/libcamera_calibration_parsers.so
%{_libdir}/libcamera_info_manager.so
%{_libdir}/libimage_transport.so
%{_libdir}/libpolled_camera.so
%{python_sitelib}/polled_camera/

%files devel
%{_datadir}/ros-stacks/%{shortname}/camera_calibration_parsers/include/
%{_datadir}/ros-stacks/%{shortname}/camera_info_manager/include/
%{_datadir}/ros-stacks/%{shortname}/image_transport/include/
%{_datadir}/ros-stacks/%{shortname}/polled_camera/include/

%changelog
* Fri Jun  1 2012 Tom Callaway <spot@fedoraproject.org> - 1.8.0-2
- fix packaging mistake

* Wed May 23 2012 Tom Callaway <spot@fedoraproject.org> - 1.8.0-1
- initial package
